==> nut-17.0.tar.gz: nut-17.0/fltk/DVValueOutput.cc <==
/* Class DVValueOutput */

/*
    NUT nutrition software 
    Copyright (C) 1996-2011 by Jim Jozwiak.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "DVValueOutput.h"
#include "Nut.h"
#include <stdio.h>
#include <FL/Fl.H>

struct food *fooodwork;

static void cal_cb(Fl_Widget *who)
{
DVValueOutput *mr_cal = (DVValueOutput *) who;
options.abnuts[ENERC_KCAL] = mr_cal->value();
Fl::check();
auto_cal(&options.abnuts[ENERC_KCAL],0,fooodwork);
Fl::check();
dv_change_minus_po();
}

static void prot_cb(Fl_Widget *who)
{
DVValueOutput *mr_prot = (DVValueOutput *) who;
options.abnuts[PROCNT] = mr_prot->value();
options.pcprotein = 0;
Fl::check();
auto_cal(&options.abnuts[ENERC_KCAL],0,fooodwork);
Fl::check();
dv_change_minus_po();
}

static void carb_cb(Fl_Widget *who)
{
DVValueOutput *mr_carb = (DVValueOutput *) who;
options.abnuts[CHOCDF] = -1 * mr_carb->value();
options.pccarb = 0;
Fl::check();
auto_cal(&options.abnuts[ENERC_KCAL],0,fooodwork);
Fl::check();
dv_change_minus_po();
}

static void fiber_cb(Fl_Widget *who)
{
DVValueOutput *mr_fiber = (DVValueOutput *) who;
options.abnuts[FIBTG] = mr_fiber->value();
Fl::check();
auto_cal(&options.abnuts[ENERC_KCAL],0,fooodwork);
Fl::check();
dv_change_minus_po();
}

static void satfat_cb(Fl_Widget *who)
{
DVValueOutput *mr_satfat = (DVValueOutput *) who;
options.pcsatfat = mr_satfat->value();
Fl::check();
auto_cal(&options.abnuts[ENERC_KCAL],0,fooodwork);
Fl::check();
dv_change_minus_po();
}

static void fish_cb(Fl_Widget *who)
{
DVValueOutput *mr_fish = (DVValueOutput *) who;
options.n6hufa = mr_fish->value();
if (options.locknuts[FAPU] == 1)
 {
 if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.abnuts[FAPU] = 0; options.locknuts[FAPU] = 0;
 options.abnuts[OMEGA6] = 0; options.locknuts[OMEGA6] = 0;
 options.abnuts[LA] = 0; options.locknuts[LA] = 0;
 options.abnuts[AA] = 0; options.locknuts[AA] = 0;
 options.abnuts[OMEGA3] = 0; options.locknuts[OMEGA3] = 0;
 options.abnuts[ALA] = 0; options.locknuts[ALA] = 0;
 options.abnuts[EPA] = 0; options.locknuts[EPA] = 0;
 options.abnuts[DHA] = 0; options.locknuts[DHA] = 0;
 }
}

static void ala_cb(Fl_Widget *who)
{
DVValueOutput *mr_ala = (DVValueOutput *) who;
options.alafactor = mr_ala->value();
if (options.locknuts[FAPU] == 1)
 {
 if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.abnuts[FAPU] = 0; options.locknuts[FAPU] = 0;
 options.abnuts[OMEGA6] = 0; options.locknuts[OMEGA6] = 0;
 options.abnuts[LA] = 0; options.locknuts[LA] = 0;
 options.abnuts[AA] = 0; options.locknuts[AA] = 0;
 options.abnuts[OMEGA3] = 0; options.locknuts[OMEGA3] = 0;
 options.abnuts[ALA] = 0; options.locknuts[ALA] = 0;
 options.abnuts[EPA] = 0; options.locknuts[EPA] = 0;
 options.abnuts[DHA] = 0; options.locknuts[DHA] = 0;
 }
}

static void epa_cb(Fl_Widget *who)
{
DVValueOutput *mr_epa = (DVValueOutput *) who;
options.epadhamax = mr_epa->value();
if (options.locknuts[FAPU] == 1)
 {
 if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.abnuts[FAPU] = 0; options.locknuts[FAPU] = 0;
 options.abnuts[OMEGA6] = 0; options.locknuts[OMEGA6] = 0;
 options.abnuts[LA] = 0; options.locknuts[LA] = 0;
 options.abnuts[AA] = 0; options.locknuts[AA] = 0;
 options.abnuts[OMEGA3] = 0; options.locknuts[OMEGA3] = 0;
 options.abnuts[ALA] = 0; options.locknuts[ALA] = 0;
 options.abnuts[EPA] = 0; options.locknuts[EPA] = 0;
 options.abnuts[DHA] = 0; options.locknuts[DHA] = 0;
 }
}

DVValueOutput::DVValueOutput (int x, int y, int w, int h, Fl_Color widgetcolor, int nutnum) : Fl_Value_Output (x, y, w, h)
{
mynut = nutnum;
this->tooltip("Click and drag left and right to adjust,\nmiddle button 10x, right button 100x");
this->textsize(FontSize);
this->textcolor(FL_YELLOW);
this->textfont(FL_BOLD);
this->color(widgetcolor);
this->box(FL_SHADOW_BOX);
this->step(0.1);
this->bounds(1, 9999);
switch (mynut)
 {
 case ENERC_KCAL:
  this->bounds(100, 9999);
  this->callback(cal_cb);
  break;
 case FIBTG:
  this->bounds(1, 200);
  this->callback(fiber_cb);
  break;  
 case CHO_NONFIB:
  this->bounds(1, 2000);
  this->callback(carb_cb);
  break;
 case PROCNT:
  this->bounds(1, 500);
  this->callback(prot_cb);
  break;
 case FASAT:
  this->bounds(1, 99);
  this->callback(satfat_cb);
  break;
 case FAPU:
  this->bounds(15, 90);
  this->step(1);
  this->callback(fish_cb);
  break;
 case ALA:
  this->step(1);
  this->bounds(1, 50);
  this->callback(ala_cb);
  break;
 case EPA:
  this->bounds(0.1, 200);
  this->callback(epa_cb);
  break;
 }
}

int DVValueOutput::format(char *buffer)
{
switch (mynut)
 {
 case ENERC_KCAL:
  #if defined FL_MINOR_VERSION && FL_MINOR_VERSION == 1
  return snprintf(buffer, 128, "%10.1f kc", value());
  #else
  return snprintf(buffer, 128, "%8.1f kc", value());
  #endif
  break;
 case FIBTG:
 case CHO_NONFIB:
 case PROCNT:
  #if defined FL_MINOR_VERSION && FL_MINOR_VERSION == 1
  return snprintf(buffer, 128, "%10.1f g", value());
  #else
  return snprintf(buffer, 128, "%8.1f g", value());
  #endif
  break;
 case FASAT:
  #if defined FL_MINOR_VERSION && FL_MINOR_VERSION == 1
  return snprintf(buffer, 128, "%10.0f%%", value());
  #else
  return snprintf(buffer, 128, "%8.0f%%", value());
  #endif
  break;
 case FAPU:
  #if defined FL_MINOR_VERSION && FL_MINOR_VERSION == 1
  return snprintf(buffer, 128, "%8.0f / %0.0f", value(), 100 - value());
  #else
  return snprintf(buffer, 128, "%6.0f / %0.0f", value(), 100 - value());
  #endif
  break;
 case ALA:
  #if defined FL_MINOR_VERSION && FL_MINOR_VERSION == 1
  return snprintf(buffer, 128, "%9.0f:1", value());
  #else
  return snprintf(buffer, 128, "%7.0f:1", value());
  #endif
  break;
 case EPA:
  #if defined FL_MINOR_VERSION && FL_MINOR_VERSION == 1
  return snprintf(buffer, 128, "%10.1f g", value());
  #else
  return snprintf(buffer, 128, "%8.1f g", value());
  #endif
  break;
 }
return 0;
}

void DVValueOutput::update(void)
{
switch (mynut)
 {
 case ENERC_KCAL:
 case FIBTG:
 case PROCNT:
  value(DV[mynut]);
  break;
 case CHO_NONFIB:
  value(DV[CHOCDF] - DV[FIBTG]);
  break;
 case FASAT:
  value(options.pcsatfat == 0 ? 10 : options.pcsatfat);
  break;
 case FAPU:
  value(options.n6hufa == 0 ? DefaultTarget : options.n6hufa);
  break;
 case ALA:
  value(options.alafactor);
  break;
 case EPA:
 value(options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
  break;
 }
}

==> nut-17.4.tar.gz: nut-17.4/fltk/DVValueOutput.cc <==
/* Class DVValueOutput */

/*
    NUT nutrition software 
    Copyright (C) 1996-2011 by Jim Jozwiak.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "DVValueOutput.h"
#include "Nut.h"
#include <stdio.h>
#include <FL/Fl.H>

struct food *fooodwork;

static void cal_cb(Fl_Widget *who)
{
DVValueOutput *mr_cal = (DVValueOutput *) who;
options.abnuts[ENERC_KCAL] = mr_cal->value();
Fl::check();
auto_cal(&options.abnuts[ENERC_KCAL],0,fooodwork);
Fl::check();
dv_change_minus_po();
}

static void prot_cb(Fl_Widget *who)
{
DVValueOutput *mr_prot = (DVValueOutput *) who;
options.abnuts[PROCNT] = mr_prot->value();
options.pcprotein = 0;
Fl::check();
auto_cal(&options.abnuts[ENERC_KCAL],0,fooodwork);
Fl::check();
dv_change_minus_po();
}

static void carb_cb(Fl_Widget *who)
{
DVValueOutput *mr_carb = (DVValueOutput *) who;
options.abnuts[CHOCDF] = -1 * mr_carb->value();
options.pccarb = 0;
Fl::check();
auto_cal(&options.abnuts[ENERC_KCAL],0,fooodwork);
Fl::check();
dv_change_minus_po();
}

static void fiber_cb(Fl_Widget *who)
{
DVValueOutput *mr_fiber = (DVValueOutput *) who;
options.abnuts[FIBTG] = mr_fiber->value();
Fl::check();
auto_cal(&options.abnuts[ENERC_KCAL],0,fooodwork);
Fl::check();
dv_change_minus_po();
}

static void satfat_cb(Fl_Widget *who)
{
DVValueOutput *mr_satfat = (DVValueOutput *) who;
options.pcsatfat = mr_satfat->value();
Fl::check();
auto_cal(&options.abnuts[ENERC_KCAL],0,fooodwork);
Fl::check();
dv_change_minus_po();
}

static void fish_cb(Fl_Widget *who)
{
DVValueOutput *mr_fish = (DVValueOutput *) who;
options.n6hufa = mr_fish->value();
if (options.locknuts[FAPU] == 1)
 {
 if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.abnuts[FAPU] = 0; options.locknuts[FAPU] = 0;
 options.abnuts[OMEGA6] = 0; options.locknuts[OMEGA6] = 0;
 options.abnuts[LA] = 0; options.locknuts[LA] = 0;
 options.abnuts[AA] = 0; options.locknuts[AA] = 0;
 options.abnuts[OMEGA3] = 0; options.locknuts[OMEGA3] = 0;
 options.abnuts[ALA] = 0; options.locknuts[ALA] = 0;
 options.abnuts[EPA] = 0; options.locknuts[EPA] = 0;
 options.abnuts[DHA] = 0; options.locknuts[DHA] = 0;
 }
}

static void ala_cb(Fl_Widget *who)
{
DVValueOutput *mr_ala = (DVValueOutput *) who;
options.alafactor = mr_ala->value();
if (options.locknuts[FAPU] == 1)
 {
 if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.abnuts[FAPU] = 0; options.locknuts[FAPU] = 0;
 options.abnuts[OMEGA6] = 0; options.locknuts[OMEGA6] = 0;
 options.abnuts[LA] = 0; options.locknuts[LA] = 0;
 options.abnuts[AA] = 0; options.locknuts[AA] = 0;
 options.abnuts[OMEGA3] = 0; options.locknuts[OMEGA3] = 0;
 options.abnuts[ALA] = 0; options.locknuts[ALA] = 0;
 options.abnuts[EPA] = 0; options.locknuts[EPA] = 0;
 options.abnuts[DHA] = 0; options.locknuts[DHA] = 0;
 }
}

static void epa_cb(Fl_Widget *who)
{
DVValueOutput *mr_epa = (DVValueOutput *) who;
options.epadhamax = mr_epa->value();
if (options.locknuts[FAPU] == 1)
 {
 if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.abnuts[FAPU] = 0; options.locknuts[FAPU] = 0;
 options.abnuts[OMEGA6] = 0; options.locknuts[OMEGA6] = 0;
 options.abnuts[LA] = 0; options.locknuts[LA] = 0;
 options.abnuts[AA] = 0; options.locknuts[AA] = 0;
 options.abnuts[OMEGA3] = 0; options.locknuts[OMEGA3] = 0;
 options.abnuts[ALA] = 0; options.locknuts[ALA] = 0;
 options.abnuts[EPA] = 0; options.locknuts[EPA] = 0;
 options.abnuts[DHA] = 0; options.locknuts[DHA] = 0;
 }
}

DVValueOutput::DVValueOutput (int x, int y, int w, int h, Fl_Color widgetcolor, int nutnum) : Nut_ValueOutput (x, y, w, h)
{
mynut = nutnum;
this->tooltip("Click and drag left and right to adjust,\nmiddle button 10x, right button 100x");
this->textcolor(FL_YELLOW);
this->textfont(FL_BOLD);
this->color(widgetcolor);
this->step(0.1);
this->bounds(1, 9999);
switch (mynut)
 {
 case ENERC_KCAL:
  this->bounds(100, 9999);
  this->callback(cal_cb);
  break;
 case FIBTG:
  this->bounds(1, 200);
  this->callback(fiber_cb);
  break;  
 case CHO_NONFIB:
  this->bounds(1, 2000);
  this->callback(carb_cb);
  break;
 case PROCNT:
  this->bounds(1, 500);
  this->callback(prot_cb);
  break;
 case FASAT:
  this->bounds(1, 99);
  this->callback(satfat_cb);
  break;
 case FAPU:
  this->bounds(15, 90);
  this->step(1);
  this->callback(fish_cb);
  break;
 case ALA:
  this->step(1);
  this->bounds(1, 50);
  this->callback(ala_cb);
  break;
 case EPA:
  this->bounds(0.1, 200);
  this->callback(epa_cb);
  break;
 }
}

int DVValueOutput::format(char *buffer)
{
switch (mynut)
 {
 case ENERC_KCAL:
  return snprintf(buffer, 128, "%0.1f kc", value());
  break;
 case FIBTG:
 case CHO_NONFIB:
 case PROCNT:
  return snprintf(buffer, 128, "%0.1f g", value());
  break;
 case FASAT:
  return snprintf(buffer, 128, "%0.0f%%", value());
  break;
 case FAPU:
  return snprintf(buffer, 128, "%0.0f / %0.0f", value(), 100 - value());
  break;
 case ALA:
  return snprintf(buffer, 128, "%0.0f:1", value());
  break;
 case EPA:
  return snprintf(buffer, 128, "%0.1f g", value());
  break;
 }
return 0;
}

void DVValueOutput::update(void)
{
switch (mynut)
 {
 case ENERC_KCAL:
 case FIBTG:
 case PROCNT:
  value(DV[mynut]);
  break;
 case CHO_NONFIB:
  value(DV[CHOCDF] - DV[FIBTG]);
  break;
 case FASAT:
  value(options.pcsatfat == 0 ? 10 : options.pcsatfat);
  break;
 case FAPU:
  value(options.n6hufa == 0 ? DefaultTarget : options.n6hufa);
  break;
 case ALA:
  value(options.alafactor);
  break;
 case EPA:
 value(options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
  break;
 }
}
